function [tn,un]=eulero(f,t0,tf,y0,Nh)
% [tn,un]=eulero(f,t0,tf,y0,Nh) Metodo di Eulero per approssimare la
% soluzione del problema di Cauchy:
%                  y'(t)=f(t,y(t))   per t in [t0,tf]
%                  y(t0)=y0
% Input: f = function handle della funzione f(t,y)
%        t0,tf = estremi dell'intervallo temporale
%        y0 = dato della condizione iniziale
%        Nh = numero di punti della discretizzazione (escluso t0)
% Output: tn = vettore colonna dei punti di discretizzazione (incluso t0)
%         un = vettore colonna della soluzione numerica (incluso u0=y0)
tn=linspace(t0,tf,Nh+1)'; % punti della discretizzazione
h=(tf-t0)/Nh;             % passo di discretizzazione
un=zeros(Nh+1,1); % inizializzo il vettore della soluzione numerica
un(1)=y0; % salvo la condizione iniziale nella prima componente del
          % vettore un
for n=1:Nh % costruisco la soluzione numerica con il metodo di Eulero
    un(n+1)=un(n)+h*f(tn(n),un(n)); 
end
