function naselli_squali_pesca(Nh)
% naselli_squali_pesca(Nh): risolve il problema Naselli e Squali con pesca
% con il metodo di Eulero e fissando Nh passi temporali
% definisco i dati del problema
t0=0; tf=80; % estremi dell'intervallo temporale
p0=5000; s0=40; % condizioni iniziali
rp=.6; rs=-.2; Kp=3.e5; sigmap=rp/Kp; % dati
sigmas=1.e-4; alpha=0.001; mu=.01;
figure(1); clf; figure(2); clf; % pulisco le figure
for bd=[0.3,0.1,0] % ciclo sui tre diversi valori di bd
f1=@(t,p,s)(rp-sigmap*p-alpha*s-bd)*p;
f2=@(t,p,s)(rs-sigmas*s+mu*alpha*p-bd)*s;
% calcolo la soluzione numerica con il metodo di Eulero
[tn,un,vn]=eulero2(f1,f2,t0,tf,p0,s0,Nh);
fprintf('bd=%2.1f, %6.0f naselli e %6.0f squali al tempo t=%d \n',...
    bd,un(end),vn(end),tf) % stampa a video
% disegno la soluzione numerica
figure(1); plot(tn,un); hold on
figure(2); plot(tn,vn); hold on
end
figure(1); grid on; xlabel('t'); ylabel('prede (naselli)'); 
legend('bd=0.3','bd=0.1','bd=0')
figure(2); grid on; xlabel('t'); ylabel('predatori (squali)'); 
legend('bd=0.3','bd=0.1','bd=0')
